as_gg_call: Convert an expression into a call as a list of quosure components
Description
Convert an expression into a call as a list of quosure components
Usage
as_gg_call(x, which = 3L)
Arguments
- x
An expression to convert to a ggcall.
- which
The relative frame offset in which the expression should be
eventually evaluated.