Learn R Programming

ggpackets (version 0.2.2)

with_ignore_unused_argument: Evaluate a call, ignore base R errors for unused arguments

Description

In actuality, the expression is repeatedly called while catching errors and removing error-causing arguments.

Usage

with_ignore_unused_argument(call, envir = parent.frame())

Arguments

call

A call to evaluate.

envir

An environment to evaluate the given expression in.